@@ -4,8 +4,9 @@ from threading import Lock
 from types import TracebackType
 from typing import ClassVar, Self, cast
 
+from haiway.attributes import State
 from haiway.context.types import MissingContext, MissingState
-from haiway.state import Immutable, State
+from haiway.types import Immutable
 
 __all__ = (
     "ScopeState",
@@ -79,7 +80,7 @@ class ScopeState(Immutable):
                     self._state[state] = initialized
                     return True
 
-                except BaseException:
+                except Exception:
                     return False  # unavailable, we don't care the exception
 
         else:
@@ -271,7 +272,15 @@ class StateContext(Immutable):
             )
 
         except LookupError as exc:
-            raise MissingContext("StateContext requested but not defined!") from exc
+            try:
+                if default is not None:
+                    return default
+
+                else:
+                    return state()
+
+            except Exception:
+                raise MissingContext("StateContext requested but not defined!") from exc
 
     @classmethod
     def updated(
